import {
  system,
  world,
  Player,
  EquipmentSlot,
  ItemStack
} from "@minecraft/server";

const scoreboard = world.scoreboard;
const playerData = new Map();

system.runInterval(() => {
  world.getAllPlayers().forEach((player) => {
    const scoreboardIdentity = player.scoreboardIdentity;
    const scoreboardObjective = scoreboard.getObjective("shield_durability");
    const currentScore = scoreboard.getScore(scoreboardObjective, scoreboardIdentity);

    if (!playerData.has(player)) {
      playerData.set(player, currentScore);
      return;
    }

    const previousScore = playerData.get(player);

    if (previousScore !== currentScore) {
      playerData.set(player, currentScore);

      const equipment = player.getComponent("equipment_inventory");
      const itemInMainhand = equipment.getEquipment("mainhand");
      const itemInOffhand = equipment.getEquipment("offhand");

      if (itemInMainhand?.typeId?.endsWith('shield')) {
        itemInMainhand.getComponent("minecraft:durability").damage++;
        equipment.setEquipment("mainhand", itemInMainhand);

        if (itemInMainhand.getComponent("minecraft:durability").damage >= itemInMainhand.getComponent("minecraft:durability").maxDurability) {
          player.runCommand("playsound random.break");
          player.runCommand("replaceitem entity @s slot.weapon.mainhand 1 air 1 1");
        }
      } else if (itemInOffhand?.typeId?.endsWith('shield')) {
        itemInOffhand.getComponent("minecraft:durability").damage++;
        equipment.setEquipment("offhand", itemInOffhand);

        if (itemInOffhand.getComponent("minecraft:durability").damage >= itemInOffhand.getComponent("minecraft:durability").maxDurability) {
          player.runCommand("playsound random.break");
          player.runCommand("replaceitem entity @s slot.weapon.offhand 1 air 1 1");
        }
      }
    }
  });
}, 4);